@@ -216,21 +216,9 @@ class SelectElement(ScreenElement):
 class CheckBoxElement(ScreenElement):
     """CheckBoxElement class that is initialized on CheckBoxElement screen object class."""
 
-    def __init__(self,
-                 locator=None,
-                 wait=10,
-                 method=ec.visibility_of_element_located,
-                 ignored_exceptions=(NoSuchElementException, StaleElementReferenceException,),
-                 fail_message=None,
-                 until_not=False,
-                 scroll_to_element=False):
-        super(CheckBoxElement, self).__init__(locator=locator,
-                                              wait=wait,
-                                              method=method,
-                                              ignored_exceptions=ignored_exceptions,
-                                              fail_message=fail_message,
-                                              until_not=until_not,
-                                              scroll_to_element=scroll_to_element)
+    def __init__(self, locator, enabled_check):
+        super(CheckBoxElement, self).__init__(locator=locator)
+        self.enabled_check = enabled_check
         self._checked = None
         self._enabled = None
 
